==> osam_flutter-3.0.2.tar.gz: lib/src/navigation/navigation_presenter.dart <==
import 'package:flutter/cupertino.dart';
import 'package:osam_flutter/osam_flutter.dart';
import 'package:osam_flutter/src/navigation/osam_route.dart';

import 'exceptions.dart';

mixin NavigationPresenter<US,AS> on Presenter<US, AS> {
  Navigation get navigation;

  void pop() => navigation.pop();

  void popUntil(String route) => navigation.popUntil(route);

  void setResult<R>({@required String route, R result}) =>
      currentRoutes.firstWhere((element) => element.value == route, orElse: throw NoRouteException()).result = result;

  Future<R> push<A, R>(OsamRoute<A, R> route) => navigation.push(route);

  Future<R> pushReplacement<A, R>(OsamRoute<A, R> route) => navigation.pushReplacement(route);

  Future<R> pushAndRemoveUntil<A, R>(OsamRoute<A, R> route) => navigation.pushAndRemoveUntil(route);

  List<OsamRoute<Object, Object>> get currentRoutes => navigation.routes.value;

  OsamRoute<Object, Object> get currentRoute => currentRoutes.last;

  OsamRoute<Object, Object> get firstRoute => currentRoutes.first;

  bool isInStack(String route) => currentRoutes.contains(route);

  bool get canPop => navigation.routes.value.length > 1;

  OsamRoute<Object, Object> get routeBefore =>
      currentRoutes.length > 1 ? currentRoutes[currentRoutes.length - 2] : throw NoRouteException();
}

mixin TabNavigationPresenter<US, AS> on Presenter<US, AS> {
  TabNavigation get tabNavigation;

  String get currentTab => tabNavigation.tabNotifier.value;

  void changeTab(String newTab) => tabNavigation.tab = newTab;
}

==> osam_flutter-3.1.7.tar.gz: lib/src/navigation/navigation_presenter.dart <==
import 'package:osam_flutter/osam_flutter.dart';
import 'package:osam_flutter/src/navigation/osam_route.dart';

mixin NavigationPresenter<US, AS> on Presenter<US, AS> {
  Navigation get navigation;

  void pop() => navigation.pop();

  void popUntil<T extends OsamRoute>() => navigation.popUntil<T>();

  void setRouteResult<T extends OsamRoute>(Object result) => findRoute<T>().result = result;

  Future<R> push<A, R>(OsamRoute<A, R> route) => navigation.push(route);

  Future<R> pushReplacement<A, R>(OsamRoute<A, R> route) => navigation.pushReplacement(route);

  Future<R> pushAndRemoveUntil<A, R>(OsamRoute<A, R> route) => navigation.pushAndRemoveUntil(route);

  List<OsamRoute<Object, Object>> get currentRoutes => navigation.routes.value;

  OsamRoute<Object, Object> get currentRoute => currentRoutes.last;

  OsamRoute<Object, Object> findRoute<T extends OsamRoute>() =>
      isInStack<T>() ? navigation.findRoute<T>() : null;

  OsamRoute<Object, Object> get firstRoute => currentRoutes.first;

  bool isInStack<T extends OsamRoute>() =>
      currentRoutes.firstWhere((element) => element is T, orElse: () => null) != null;

  bool get canPop => navigation.routes.value.length > 1;

  OsamRoute<Object, Object> get routeBefore =>
      currentRoutes.length > 1 ? currentRoutes[currentRoutes.length - 2] : throw null;
}

mixin TabNavigationPresenter<US, AS> on Presenter<US, AS> {
  TabNavigation get tabNavigation;

  String get currentTab => tabNavigation.tabNotifier.value;

  void changeTab(String newTab) => tabNavigation.tab = newTab;
}
